"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .paymentmethodcard import PaymentMethodCard, PaymentMethodCardTypedDict
from .paymentmethodgeneric import PaymentMethodGeneric, PaymentMethodGenericTypedDict
from typing import Union
from typing_extensions import TypeAliasType


CustomerPaymentMethodTypedDict = TypeAliasType(
    "CustomerPaymentMethodTypedDict",
    Union[PaymentMethodGenericTypedDict, PaymentMethodCardTypedDict],
)


CustomerPaymentMethod = TypeAliasType(
    "CustomerPaymentMethod", Union[PaymentMethodGeneric, PaymentMethodCard]
)
