"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from typing_extensions import TypedDict


class CardPaymentMetadataTypedDict(TypedDict):
    r"""Additional metadata for a card payment method."""

    brand: str
    r"""The brand of the card used for the payment."""
    last4: str
    r"""The last 4 digits of the card number."""


class CardPaymentMetadata(BaseModel):
    r"""Additional metadata for a card payment method."""

    brand: str
    r"""The brand of the card used for the payment."""

    last4: str
    r"""The last 4 digits of the card number."""
