"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from polar_sdk.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


class CustomerBenefitGrantMeterCreditUpdateTypedDict(TypedDict):
    benefit_type: Literal["meter_credit"]


class CustomerBenefitGrantMeterCreditUpdate(BaseModel):
    BENEFIT_TYPE: Annotated[
        Annotated[
            Literal["meter_credit"], AfterValidator(validate_const("meter_credit"))
        ],
        pydantic.Field(alias="benefit_type"),
    ] = "meter_credit"
