"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .systemevent import SystemEvent, SystemEventTypedDict
from .userevent import UserEvent, UserEventTypedDict
from typing import Union
from typing_extensions import TypeAliasType


EventTypedDict = TypeAliasType(
    "EventTypedDict", Union[UserEventTypedDict, SystemEventTypedDict]
)


Event = TypeAliasType("Event", Union[UserEvent, SystemEvent])
