"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .benefitgrantwebhook import BenefitGrantWebhook, BenefitGrantWebhookTypedDict
from polar_sdk.types import BaseModel
from polar_sdk.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


class WebhookBenefitGrantCreatedPayloadTypedDict(TypedDict):
    r"""Sent when a new benefit grant is created.

    **Discord & Slack support:** Basic
    """

    data: BenefitGrantWebhookTypedDict
    type: Literal["benefit_grant.created"]


class WebhookBenefitGrantCreatedPayload(BaseModel):
    r"""Sent when a new benefit grant is created.

    **Discord & Slack support:** Basic
    """

    data: BenefitGrantWebhook

    TYPE: Annotated[
        Annotated[
            Literal["benefit_grant.created"],
            AfterValidator(validate_const("benefit_grant.created")),
        ],
        pydantic.Field(alias="type"),
    ] = "benefit_grant.created"
