"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .subscriptioncancel import SubscriptionCancel, SubscriptionCancelTypedDict
from .subscriptionrevoke import SubscriptionRevoke, SubscriptionRevokeTypedDict
from .subscriptionupdatediscount import (
    SubscriptionUpdateDiscount,
    SubscriptionUpdateDiscountTypedDict,
)
from .subscriptionupdateproduct import (
    SubscriptionUpdateProduct,
    SubscriptionUpdateProductTypedDict,
)
from typing import Union
from typing_extensions import TypeAliasType


SubscriptionUpdateTypedDict = TypeAliasType(
    "SubscriptionUpdateTypedDict",
    Union[
        SubscriptionUpdateDiscountTypedDict,
        SubscriptionUpdateProductTypedDict,
        SubscriptionCancelTypedDict,
        SubscriptionRevokeTypedDict,
    ],
)


SubscriptionUpdate = TypeAliasType(
    "SubscriptionUpdate",
    Union[
        SubscriptionUpdateDiscount,
        SubscriptionUpdateProduct,
        SubscriptionCancel,
        SubscriptionRevoke,
    ],
)
